@@ -106,6 +106,9 @@ typedef enum {
                                            other category */
     LPI_CATEGORY_ICS,           /* Industrial control system protocols */
         LPI_CATEGORY_IPCAMERAS,         /* IP Surveillance Camera protocols */
+        LPI_CATEGORY_MESSAGE_QUEUE,     /* Message queuing protocols */
+        LPI_CATEGORY_EDUCATIONAL,     /* Educational applications, e.g. virtual
+                                         classrooms */
 	LPI_CATEGORY_ICMP,		/* ICMP */
 	LPI_CATEGORY_MIXED,		/* Different protos in each direction */
 	LPI_CATEGORY_NOPAYLOAD,		/* No payload observed */
@@ -367,6 +370,39 @@ typedef enum {
         LPI_PROTO_LITECOIN,
         LPI_PROTO_STRATUM,
         LPI_PROTO_WIZARD101,
+        LPI_PROTO_KINGOFGLORY,
+        LPI_PROTO_SAS_ZOMBIE_ASSAULT_4,
+        LPI_PROTO_DNF,
+        LPI_PROTO_IHEXIN,
+        LPI_PROTO_NAVER_P2P,
+        LPI_PROTO_GCAFE_UPDATER,
+        LPI_PROTO_BWSYNC,
+        LPI_PROTO_TANKIONLINE,
+        LPI_PROTO_REALMOFTHEMADGOD,
+        LPI_PROTO_PATHOFEXILE,
+        LPI_PROTO_SSJJ,
+        LPI_PROTO_SPEEDIFY,
+        LPI_PROTO_NSQ,
+        LPI_PROTO_SKYFORGE,
+        LPI_PROTO_HOTS,
+        LPI_PROTO_NOMACHINE,
+        LPI_PROTO_QQSPEEDMOBILE,
+        LPI_PROTO_DAHUA,
+        LPI_PROTO_UTHERVERSE,
+        LPI_PROTO_300_HEROES,
+        LPI_PROTO_FILENORI,
+        LPI_PROTO_IPFS,
+        LPI_PROTO_REMOTE_MANIPULATOR,
+        LPI_PROTO_WEBEX_STUN,
+        LPI_PROTO_RRTV,
+        LPI_PROTO_RABBITMQ,
+        LPI_PROTO_ICEP,
+        LPI_PROTO_BEAM,
+        LPI_PROTO_VHDP2P,
+        LPI_PROTO_CLASSIN,
+        LPI_PROTO_TRANSOCKS,
+        LPI_PROTO_RAGNAROK_ONLINE,
+	LPI_PROTO_ETHERNETIP,
 
         /* UDP Protocols */
         LPI_PROTO_UDP,
@@ -384,6 +420,8 @@ typedef enum {
         LPI_PROTO_UDP_EMULE,
         LPI_PROTO_UDP_EYE,
         LPI_PROTO_UDP_RTP,
+        LPI_PROTO_UDP_ETHERNETIP,
+	LPI_PROTO_UDP_CIP_IO, /* Common industrial protocol IO */
         LPI_PROTO_UDP_MSN_VIDEO,
         LPI_PROTO_UDP_COD,     /* Call of Duty game protocol */
         LPI_PROTO_UDP_NTP,
@@ -488,7 +526,7 @@ typedef enum {
 	LPI_PROTO_UDP_SPOTIFY_BROADCAST,
 	LPI_PROTO_UDP_MDNS,	/* Multicast DNS */
 	LPI_PROTO_UDP_FASP,
-	LPI_PROTO_UDP_ROBLOX,
+	LPI_PROTO_UDP_RAKNET,
 	LPI_PROTO_UDP_OPENVPN,
 	LPI_PROTO_UDP_NOE,	/* Alcatel's New Office Environment */
 	LPI_PROTO_UDP_VIBER,
@@ -579,6 +617,36 @@ typedef enum {
         LPI_PROTO_UDP_COMBATARMS,
         LPI_PROTO_UDP_COMBATARMS_P2P,
         LPI_PROTO_UDP_PANIPANI,
+        LPI_PROTO_UDP_FEITWO,
+        LPI_PROTO_UDP_MOONHUNTERS,
+        LPI_PROTO_UDP_HELIBORNE,
+        LPI_PROTO_UDP_KINGOFGLORY,
+        LPI_PROTO_UDP_ASSETTO_CORSA,
+        LPI_PROTO_UDP_CACAOWEB,
+        LPI_PROTO_UDP_ZALO_CALL,
+        LPI_PROTO_UDP_PALADINS,
+        LPI_PROTO_UDP_CHARGEN_EXPLOIT,
+        LPI_PROTO_UDP_TOX,
+        LPI_PROTO_UDP_HOLLA,
+        LPI_PROTO_UDP_RRSHARE,
+        LPI_PROTO_UDP_QQSPEEDMOBILE,
+        LPI_PROTO_UDP_LOADOUT,
+        LPI_PROTO_UDP_GANGLIA,
+        LPI_PROTO_UDP_TALESRUNNER,
+        LPI_PROTO_UDP_FREEFIRE,
+        LPI_PROTO_UDP_HEROES_EVOLVED,
+        LPI_PROTO_UDP_RULES_OF_SURVIVAL,
+        LPI_PROTO_UDP_CONTRACT_WARS,
+        LPI_PROTO_UDP_ARD,
+        LPI_PROTO_UDP_QVOD,
+        LPI_PROTO_UDP_YUANFUDAO,
+        LPI_PROTO_UDP_ROCKET_LEAGUE,
+        LPI_PROTO_UDP_CLOUDFLARE_WARP,
+        LPI_PROTO_UDP_WIREGUARD,
+        LPI_PROTO_UDP_COD_MOBILE,
+        LPI_PROTO_UDP_NVIDIA_GAMESTREAM,
+        LPI_PROTO_UDP_CLASSIN,
+        LPI_PROTO_UDP_ARTCP,
 
 	/* Patterns that we can match, but do not know the protocol */
 	LPI_PROTO_REJECTION,	/* All responses are 0x02 */
@@ -589,7 +657,6 @@ typedef enum {
 	LPI_PROTO_MYSTERY_CONN,
 	LPI_PROTO_MYSTERY_SYMANTEC,
 	LPI_PROTO_MYSTERY_RXXF,
-	LPI_PROTO_MYSTERY_100_STAR,
 	
 	LPI_PROTO_UDP_MYSTERY_0D,	
 	LPI_PROTO_UDP_MYSTERY_99,
@@ -605,6 +672,7 @@ typedef enum {
 
         LPI_PROTO_INVALID,     /* No single valid protocol */
 	LPI_PROTO_NO_PAYLOAD,
+	LPI_PROTO_NO_FIRSTPKT,
 	LPI_PROTO_UNSUPPORTED,
         LPI_PROTO_UNKNOWN,
 	LPI_PROTO_LAST		/** ALWAYS have this as the last value */
@@ -726,6 +794,33 @@ const char *lpi_print_category(lpi_category_t category);
  */
 lpi_module_t *lpi_guess_protocol(lpi_data_t *data);
 
+/** Given the protocol name, returns the lpi protcol it matches.
+ *
+ * @param name The protocol name
+ *
+ * @returns The LPI protocol for the supplied name.
+ *          LPI_PROTO_UNKNOWN if the name is not found.
+ */
+lpi_protocol_t lpi_get_protocol_by_name(char *name);
+
+/* Give the category name, returns the lpi category it matches.
+ *
+ * @param name The protocol name
+ *
+ * @returns the LPI category for the supplied name on success.
+ *          LPI_CATEGORY_UNKNOWN if the name is not found.
+ */
+lpi_category_t lpi_get_category_by_name(char *name);
+
+/* Given the lpi protocol, returns the lpi category it matches.
+ *
+ * @param protocol The lpi protocol
+ *
+ * @returns the lpi category for the supplied lpi protocol.
+ *          LPI_CATEGORY_UNKNOWN if the category is not found.
+ */
+lpi_category_t lpi_get_category_by_protocol(lpi_protocol_t protocol);
+
 /** Determines whether the protocol matching a given protocol number is no
  *  longer supported by libprotoident.
  *
