@@ -327,6 +327,10 @@ bool match_file_header(uint32_t payload) {
         if (MATCH(payload, 't', 't', 'c', 'f'))
                 return true;
 
+        /* RIR delegation files... */
+        if (MATCH(payload, '2', '.', '3', '|'))
+                return true;
+
         /* REBASE -- restriction enzyme database
          * A bit niche, but might be fairly common at universities? */
         if (MATCH(payload, 0x20, 0x0a, 'R', 'E'))
@@ -415,7 +419,6 @@ static inline bool match_tls_handshake(uint32_t payload, uint32_t len) {
  * XXX This isn't always true - consecutive packets may be merged it seems :(
  */
 static inline bool match_ssl2_handshake(uint32_t payload, uint32_t len) {
-        uint32_t stated_len = 0;
 
         if (MATCH(payload, 0x80, ANY, 0x01, 0x03))
                 return true;
@@ -725,6 +728,10 @@ static inline bool match_kaspersky_ke(uint32_t payload, uint32_t len) {
                 return true;
         if (MATCH(payload, 'K', 'E', 0x00, 0x00))
                 return true;
+        if (MATCH(payload, 'K', 'E', 0x00, 0x02))
+                return true;
+        if (MATCH(payload, 'K', 'E', 0x00, 0x07))
+                return true;
         return false;
 }
 
@@ -792,7 +799,6 @@ bool match_tpkt(uint32_t payload, uint32_t len) {
 
 bool match_qqlive_payload(uint32_t payload, uint32_t len) {
 
-        uint8_t *ptr;
         uint32_t swap;
 
         /* This appears to have a 3 byte header. First byte is always 0xfe.
