@@ -132,7 +132,6 @@ typedef struct ident {
 static void *start_processing(libtrace_t *trace, libtrace_thread_t *thread,
                 void *global) {
 
-        bool opt_true = true;
         bool opt_false = false;
         struct globalopts *opts = (struct globalopts *)global;
 
@@ -239,8 +238,6 @@ char *display_ident(Flow *f, IdentFlow *ident, struct globalopts *opts)
         char iat_stats_in[200];
         char *str;
         lpi_module_t *proto;
-	struct ident_stats *is;
-	int i;
 
 	if (opts->only_dir0 && ident->init_dir == 1)
 		return NULL;
@@ -258,7 +255,7 @@ char *display_ident(Flow *f, IdentFlow *ident, struct globalopts *opts)
 	f->id.get_server_ip_str(s_ip);
 	f->id.get_client_ip_str(c_ip);
 
-        str = (char *)malloc(750);
+        str = (char *)malloc(1000);
 
         dump_len_stats(&ident->out, len_stats_out, 200);
         dump_len_stats(&ident->in, len_stats_in, 200);
@@ -266,7 +263,7 @@ char *display_ident(Flow *f, IdentFlow *ident, struct globalopts *opts)
         dump_iat_stats(&ident->in, iat_stats_in, 200);
 
 	/* basic statistics */
-	snprintf(str, 749,
+	snprintf(str, 999,
                 "%s,%d,%" PRIu64 ",%" PRIu64 ",%" PRIu64 ",%" PRIu64
                 "%s%s%s%s,%.0f,%f\n",
 		proto->name, f->id.get_protocol(),
@@ -290,7 +287,6 @@ void expire_ident_flows(libtrace_t *trace, libtrace_thread_t *thread,
                 double ts, bool exp_flag)
 {
 	Flow *expired;
-	lpi_module_t *proto;
         char *result = NULL;
         libtrace_generic_t gen;
 
@@ -402,7 +398,7 @@ static libtrace_packet_t *per_packet(libtrace_t *trace,
                 libtrace_packet_t *packet) {
 	Flow *f;
 	IdentFlow *ident = NULL;
-	uint8_t dir;
+	uint8_t dir = 255;
 	bool is_new = false;
 
 	libtrace_tcp_t *tcp = NULL;
@@ -505,22 +501,16 @@ static void usage(char *prog)
 
 int main(int argc, char *argv[])
 {
-	libtrace_t *trace;
-	libtrace_packet_t *packet;
 	libtrace_filter_t *filter = NULL;
 	struct sigaction sigact;
         struct globalopts opts;
         int threads = 1;
         int bufferresults = 10;
 
-	bool opt_true = true;
-	bool opt_false = false;
-
 	int i, opt;
 	double ts;
 	char *filterstring = NULL;
 	int dir;
-	bool ignore_rfc1918 = false;
 
         libtrace_callback_set_t *processing, *reporter;
 
